@@ -15,11 +15,11 @@ App::Prove - Implements the C<prove> command.
 
 =head1 VERSION
 
-Version 3.06
+Version 3.08
 
 =cut
 
-$VERSION = '3.06';
+$VERSION = '3.08';
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ BEGIN {
       harness includes modules plugins jobs lib merge parse quiet
       really_quiet recurse backwards shuffle taint_fail taint_warn timer
       verbose warnings_fail warnings_warn show_help show_man
-      show_version test_args state
+      show_version test_args state dry
     );
     for my $attr (@ATTR) {
         no strict 'refs';
@@ -190,7 +190,9 @@ sub process_args {
             'b|blib'      => \$self->{blib},
             's|shuffle'   => \$self->{shuffle},
             'color!'      => \$self->{color},
+            'colour!'     => \$self->{color},
             'c'           => \$self->{color},
+            'D|dry'       => \$self->{dry},
             'harness=s'   => \$self->{harness},
             'formatter=s' => \$self->{formatter},
             'r|recurse'   => \$self->{recurse},
@@ -393,27 +395,38 @@ sub run {
     elsif ( $self->show_version ) {
         $self->print_version;
     }
+    elsif ( $self->dry ) {
+        print "$_\n" for $self->_get_tests;
+    }
     else {
 
         $self->_load_extensions( $self->modules );
         $self->_load_extensions( $self->plugins, PLUGINS );
 
-        my $state = $self->{_state};
-        if ( defined( my $state_switch = $self->state ) ) {
-            $state->apply_switch(@$state_switch);
-        }
+        local $ENV{TEST_VERBOSE} = 1 if $self->verbose;
 
-        my @tests = $state->get_tests( $self->recurse, @{ $self->argv } );
-
-        $self->_shuffle(@tests) if $self->shuffle;
-        @tests = reverse @tests if $self->backwards;
-
-        $self->_runtests( $self->_get_args, @tests );
+        $self->_runtests( $self->_get_args, $self->_get_tests );
     }
 
     return;
 }
 
+sub _get_tests {
+    my $self = shift;
+
+    my $state = $self->{_state};
+    if ( defined( my $state_switch = $self->state ) ) {
+        $state->apply_switch(@$state_switch);
+    }
+
+    my @tests = $state->get_tests( $self->recurse, @{ $self->argv } );
+
+    $self->_shuffle(@tests) if $self->shuffle;
+    @tests = reverse @tests if $self->backwards;
+
+    return @tests;
+}
+
 sub _runtests {
     my ( $self, $args, $harness_class, @tests ) = @_;
     my $harness = $harness_class->new($args);
@@ -449,6 +462,10 @@ sub _get_switches {
         push @switches, '-w';
     }
 
+    if ( defined( my $hps = $ENV{HARNESS_PERL_SWITCHES} ) ) {
+        push @switches, $hps;
+    }
+
     return @switches ? \@switches : ();
 }
 
@@ -546,6 +563,8 @@ calling C<run>.
 
 =item C<directives>
 
+=item C<dry>
+
 =item C<exec>
 
 =item C<failures>
